ClassModel class

A data class representing information about a Dart class and its methods.

Instances of this class provide a convenient way to store and access details about a Dart class, including its name and the count of methods it has.

Constructors

ClassModel({required String className, required int methodCount})
Creates a new instance of ClassModel with the given class name and method count.
const

Properties

className String
The name of the Dart class.
final
hashCode int
The hash code for this object.
no setterinherited
methodCount int
The number of methods in the Dart class.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited