ClassModel constructor
Creates a new instance of ClassModel with the given class name and method count.
Implementation
const ClassModel({
required this.className,
required this.methodCount,
});
Creates a new instance of ClassModel with the given class name and method count.
const ClassModel({
required this.className,
required this.methodCount,
});